@@ -1,4 +1,4 @@
-/* 07aug14abu
+/* 30jan15abu
  * (c) Software Lab. Alexander Burger
  */
 
@@ -1955,11 +1955,13 @@ static any parse(any x, bool skp, any s) {
       cell c2;
 
       if (!(x = token(s,0)))
-         return Nil;
-      Push(c2, y = cons(x,Nil));
-      while (x = token(s,0))
-         y = cdr(y) = cons(x,Nil);
-      x = Pop(c2);
+         x = Nil;
+      else {
+         Push(c2, y = cons(x,Nil));
+         while (x = token(s,0))
+            y = cdr(y) = cons(x,Nil);
+         x = Pop(c2);
+      }
    }
    drop(c1);
    Chr = c,  Env.get = getSave,  Env.parser = save;
@@ -2175,26 +2177,31 @@ any doPipe(any ex) {
    } f;
    int pfd[2];
 
-   if (pipe(pfd) < 0)
+   if ((isCell(cddr(ex))? pipe(pfd) : socketpair(AF_UNIX, SOCK_STREAM, 0, pfd)) < 0  ||  pfd[1] < 2)
       err(ex, NULL, "Can't pipe");
    closeOnExec(ex, pfd[0]), closeOnExec(ex, pfd[1]);
    if ((f.in.pid = forkLisp(ex)) == 0) {
+      close(pfd[0]);
       if (isCell(cddr(ex)))
          setpgid(0,0);
-      close(pfd[0]);
-      if (pfd[1] != STDOUT_FILENO)
-         dup2(pfd[1], STDOUT_FILENO),  close(pfd[1]);
-      wrOpen(ex, Nil, &f.out);
+      else
+         dup2(pfd[1], STDIN_FILENO);
+      dup2(pfd[1], STDOUT_FILENO);
+      close(pfd[1]);
+      signal(SIGPIPE, SIG_DFL);
+      f.out.pid = 0,  f.out.fd = STDOUT_FILENO;
       pushOutFiles(&f.out);
       OutFile->tty = NO;
-      val(Run) = Nil;
+      val(Led) = val(Run) = Nil;
       EVAL(cadr(ex));
       bye(0);
    }
    close(pfd[1]);
    initInFile(f.in.fd = pfd[0], NULL);
-   if (!isCell(cddr(ex)))
+   if (!isCell(cddr(ex))) {
+      initOutFile(pfd[0]);
       return boxCnt(pfd[0]);
+   }
    setpgid(f.in.pid,0);
    pushInFiles(&f.in);
    x = prog(cddr(ex));
@@ -2923,7 +2930,7 @@ bool isLife(any x) {
             }
          }
       }
-      else if (!isNil(val(Ext)))
+      else if (isCell(val(Ext)))
          return YES;
    }
    return NO;
@@ -3509,7 +3516,7 @@ any doRollback(any x) {
    int i;
    any y, z;
 
-   if (!Files)
+   if (!Files && !isCell(val(Ext)))
       return Nil;
    for (i = 0; i < EHASH; ++i) {
       for (x = Extern[i];  isCell(x);  x = cdr(x)) {
@@ -3524,7 +3531,8 @@ any doRollback(any x) {
    }
    if (isCell(x = val(Zap)))
       car(x) = Nil;
-   rwUnlock(0);  // Unlock all
+   if (Files)
+      rwUnlock(0);  // Unlock all
    unsync();
    return T;
 }
