@@ -1,4 +1,4 @@
-/* 25mar14abu
+/* 30jan15abu
  * (c) Software Lab. Alexander Burger
  */
 
@@ -27,6 +27,10 @@
 #ifndef NOWAIT
 #include <sys/wait.h> // tcc doen't like it
 #endif
+#include <netdb.h>
+#include <arpa/inet.h>
+#include <netinet/in.h>
+#include <sys/socket.h>
 
 #ifndef __CYGWIN__
 #define MAIN main
@@ -516,6 +520,7 @@ any doEqT(any);
 any doEqual(any);
 any doErr(any);
 any doEval(any);
+any doExec(any);
 any doExt(any);
 any doExtern(any);
 any doExtQ(any);
@@ -673,6 +678,7 @@ any doProtect(any);
 any doProve(any);
 any doPush(any);
 any doPush1(any);
+any doPush1q(any);
 any doPut(any);
 any doPutl(any);
 any doPwd(any);
